@@ -1189,7 +1189,7 @@ gdouble
 gok_data_get_valuator_sensitivity (void)
 {
 	/* TODO: implement in gconf */
-	return 1.0;
+	return 0.25;
 }
 
 void 
@@ -1229,7 +1229,7 @@ gok_data_get_aux_dictionaries (void)
  *
  */
 void
-gok_data_set_aux_dictionaries (const gchar *dictionaries)
+gok_data_set_aux_dictionaries (gchar *dictionaries)
 {
 	m_AuxDicts = dictionaries;
 	gok_gconf_set_string (gconf_client, GOK_GCONF_AUX_DICTS,
