@@ -215,7 +215,7 @@ utf8_wordcomplete_predict_string (GokWordComplete *complete, const gchar* word,
 		WordPrediction *prediction;
 		++n;
 		prediction = g_slist_nth_data (predictions, n);
-		word_predict_list [n] = prediction ? strdup (prediction->string) : NULL;
+		word_predict_list [n] = prediction ? g_strdup (prediction->string) : NULL;
 	} while (word_predict_list [n] && n < num_predictions);
 
 	word_predict_list [num_predictions] = NULL; /* in case predictions-length >= num_predictions */
@@ -235,7 +235,7 @@ utf8_wordcomplete_predict_string (GokWordComplete *complete, const gchar* word,
 
 	if (utf8_complete->most_recent_word) 
 		g_free (utf8_complete->most_recent_word);
-	utf8_complete->most_recent_word = strdup (word);
+	utf8_complete->most_recent_word = g_strdup (word);
 
 	return word_predict_list; /* predictions made! */
 }
